import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { CloudFormationServiceException as __BaseException } from "./CloudFormationServiceException";
import {
  AutoDeployment,
  CallAs,
  Capability,
  DeploymentTargets,
  LoggingConfig,
  ManagedExecution,
  Parameter,
  PermissionModels,
  RegistryType,
  ResourceDefinition,
  RollbackConfiguration,
  StackSetOperationPreferences,
  Tag,
  TemplateConfiguration,
  ThirdPartyType,
} from "./models_0";
export interface RegisterTypeInput {
  Type?: RegistryType | undefined;
  TypeName: string | undefined;
  SchemaHandlerPackage: string | undefined;
  LoggingConfig?: LoggingConfig | undefined;
  ExecutionRoleArn?: string | undefined;
  ClientRequestToken?: string | undefined;
}
export interface RegisterTypeOutput {
  RegistrationToken?: string | undefined;
}
export interface RollbackStackInput {
  StackName: string | undefined;
  RoleARN?: string | undefined;
  ClientRequestToken?: string | undefined;
  RetainExceptOnCreate?: boolean | undefined;
}
export interface RollbackStackOutput {
  StackId?: string | undefined;
}
export interface SetStackPolicyInput {
  StackName: string | undefined;
  StackPolicyBody?: string | undefined;
  StackPolicyURL?: string | undefined;
}
export interface SetTypeConfigurationInput {
  TypeArn?: string | undefined;
  Configuration: string | undefined;
  ConfigurationAlias?: string | undefined;
  TypeName?: string | undefined;
  Type?: ThirdPartyType | undefined;
}
export interface SetTypeConfigurationOutput {
  ConfigurationArn?: string | undefined;
}
export interface SetTypeDefaultVersionInput {
  Arn?: string | undefined;
  Type?: RegistryType | undefined;
  TypeName?: string | undefined;
  VersionId?: string | undefined;
}
export interface SetTypeDefaultVersionOutput {}
export declare const ResourceSignalStatus: {
  readonly FAILURE: "FAILURE";
  readonly SUCCESS: "SUCCESS";
};
export type ResourceSignalStatus =
  (typeof ResourceSignalStatus)[keyof typeof ResourceSignalStatus];
export interface SignalResourceInput {
  StackName: string | undefined;
  LogicalResourceId: string | undefined;
  UniqueId: string | undefined;
  Status: ResourceSignalStatus | undefined;
}
export declare class ResourceScanLimitExceededException extends __BaseException {
  readonly name: "ResourceScanLimitExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      ResourceScanLimitExceededException,
      __BaseException
    >
  );
}
export interface StartResourceScanInput {
  ClientRequestToken?: string | undefined;
}
export interface StartResourceScanOutput {
  ResourceScanId?: string | undefined;
}
export interface StopStackSetOperationInput {
  StackSetName: string | undefined;
  OperationId: string | undefined;
  CallAs?: CallAs | undefined;
}
export interface StopStackSetOperationOutput {}
export interface TestTypeInput {
  Arn?: string | undefined;
  Type?: ThirdPartyType | undefined;
  TypeName?: string | undefined;
  VersionId?: string | undefined;
  LogDeliveryBucket?: string | undefined;
}
export interface TestTypeOutput {
  TypeVersionArn?: string | undefined;
}
export interface UpdateGeneratedTemplateInput {
  GeneratedTemplateName: string | undefined;
  NewGeneratedTemplateName?: string | undefined;
  AddResources?: ResourceDefinition[] | undefined;
  RemoveResources?: string[] | undefined;
  RefreshAllResources?: boolean | undefined;
  TemplateConfiguration?: TemplateConfiguration | undefined;
}
export interface UpdateGeneratedTemplateOutput {
  GeneratedTemplateId?: string | undefined;
}
export interface UpdateStackInput {
  StackName: string | undefined;
  TemplateBody?: string | undefined;
  TemplateURL?: string | undefined;
  UsePreviousTemplate?: boolean | undefined;
  StackPolicyDuringUpdateBody?: string | undefined;
  StackPolicyDuringUpdateURL?: string | undefined;
  Parameters?: Parameter[] | undefined;
  Capabilities?: Capability[] | undefined;
  ResourceTypes?: string[] | undefined;
  RoleARN?: string | undefined;
  RollbackConfiguration?: RollbackConfiguration | undefined;
  StackPolicyBody?: string | undefined;
  StackPolicyURL?: string | undefined;
  NotificationARNs?: string[] | undefined;
  Tags?: Tag[] | undefined;
  DisableRollback?: boolean | undefined;
  ClientRequestToken?: string | undefined;
  RetainExceptOnCreate?: boolean | undefined;
}
export interface UpdateStackOutput {
  StackId?: string | undefined;
}
export interface UpdateStackInstancesInput {
  StackSetName: string | undefined;
  Accounts?: string[] | undefined;
  DeploymentTargets?: DeploymentTargets | undefined;
  Regions: string[] | undefined;
  ParameterOverrides?: Parameter[] | undefined;
  OperationPreferences?: StackSetOperationPreferences | undefined;
  OperationId?: string | undefined;
  CallAs?: CallAs | undefined;
}
export interface UpdateStackInstancesOutput {
  OperationId?: string | undefined;
}
export interface UpdateStackSetInput {
  StackSetName: string | undefined;
  Description?: string | undefined;
  TemplateBody?: string | undefined;
  TemplateURL?: string | undefined;
  UsePreviousTemplate?: boolean | undefined;
  Parameters?: Parameter[] | undefined;
  Capabilities?: Capability[] | undefined;
  Tags?: Tag[] | undefined;
  OperationPreferences?: StackSetOperationPreferences | undefined;
  AdministrationRoleARN?: string | undefined;
  ExecutionRoleName?: string | undefined;
  DeploymentTargets?: DeploymentTargets | undefined;
  PermissionModel?: PermissionModels | undefined;
  AutoDeployment?: AutoDeployment | undefined;
  OperationId?: string | undefined;
  Accounts?: string[] | undefined;
  Regions?: string[] | undefined;
  CallAs?: CallAs | undefined;
  ManagedExecution?: ManagedExecution | undefined;
}
export interface UpdateStackSetOutput {
  OperationId?: string | undefined;
}
export interface UpdateTerminationProtectionInput {
  EnableTerminationProtection: boolean | undefined;
  StackName: string | undefined;
}
export interface UpdateTerminationProtectionOutput {
  StackId?: string | undefined;
}
export interface ValidateTemplateInput {
  TemplateBody?: string | undefined;
  TemplateURL?: string | undefined;
}
export interface TemplateParameter {
  ParameterKey?: string | undefined;
  DefaultValue?: string | undefined;
  NoEcho?: boolean | undefined;
  Description?: string | undefined;
}
export interface ValidateTemplateOutput {
  Parameters?: TemplateParameter[] | undefined;
  Description?: string | undefined;
  Capabilities?: Capability[] | undefined;
  CapabilitiesReason?: string | undefined;
  DeclaredTransforms?: string[] | undefined;
}
